==> james-project-3.4.0-source-release.zip: james-project-3.4.0/server/mailet/mailetcontainer-camel/src/test/java/org/apache/james/mailetcontainer/impl/matchers/OrTest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailetcontainer.impl.matchers;

import static org.apache.mailet.base.MailAddressFixture.ANY_AT_JAMES;
import static org.apache.mailet.base.MailAddressFixture.ANY_AT_JAMES2;
import static org.apache.mailet.base.MailAddressFixture.OTHER_AT_JAMES;
import static org.apache.mailet.base.MailAddressFixture.OTHER_AT_JAMES2;
import static org.assertj.core.api.Assertions.assertThat;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import org.apache.james.core.MailAddress;
import org.apache.mailet.Mail;
import org.apache.mailet.Matcher;
import org.apache.mailet.base.test.FakeMail;
import org.junit.Before;
import org.junit.Test;

import com.google.common.collect.ImmutableList;

public class OrTest {

    private Or testee;
    private Matcher matcher1;
    private Matcher matcher2;
    private Mail mail;

    @Before
    public void setUp() throws Exception {
        matcher1 = mock(Matcher.class);
        matcher2 = mock(Matcher.class);

        testee = new Or();

        mail = FakeMail.builder().name("name").recipients(ANY_AT_JAMES, OTHER_AT_JAMES, ANY_AT_JAMES2, OTHER_AT_JAMES2).build();
    }

    @Test
    public void shouldReturnNoResultWhenNoMatcherSpecified() throws Exception {
        assertThat(testee.match(mail)).isEmpty();
    }

    @Test
    public void shouldReturnMatchResultWhenOnlyOneMatcher() throws Exception {
        when(matcher1.match(mail)).thenReturn(ImmutableList.of(ANY_AT_JAMES, ANY_AT_JAMES2));

        testee.add(matcher1);

        assertThat(testee.match(mail)).containsOnly(ANY_AT_JAMES, ANY_AT_JAMES2);
    }

    @Test
    public void shouldReturnUnionWhenTwoMatchers() throws Exception {
        when(matcher1.match(mail)).thenReturn(ImmutableList.of(ANY_AT_JAMES, ANY_AT_JAMES2));
        when(matcher2.match(mail)).thenReturn(ImmutableList.of(ANY_AT_JAMES, OTHER_AT_JAMES));

        testee.add(matcher1);
        testee.add(matcher2);

        assertThat(testee.match(mail)).containsOnly(ANY_AT_JAMES, ANY_AT_JAMES2, OTHER_AT_JAMES);
    }

    @Test
    public void shouldAcceptEmptyResults() throws Exception {
        when(matcher1.match(mail)).thenReturn(ImmutableList.of(ANY_AT_JAMES, ANY_AT_JAMES2));
        when(matcher2.match(mail)).thenReturn(ImmutableList.<MailAddress>of());

        testee.add(matcher1);
        testee.add(matcher2);

        assertThat(testee.match(mail)).containsOnly(ANY_AT_JAMES, ANY_AT_JAMES2);
    }

    @Test
    public void shouldAcceptNullResults() throws Exception {
        when(matcher1.match(mail)).thenReturn(ImmutableList.of(ANY_AT_JAMES, ANY_AT_JAMES2));
        when(matcher2.match(mail)).thenReturn(null);

        testee.add(matcher1);
        testee.add(matcher2);

        assertThat(testee.match(mail)).containsOnly(ANY_AT_JAMES, ANY_AT_JAMES2);
    }
}

==> james-project-3.5.0-source-release.zip: james-project-3.5.0/server/mailet/mailetcontainer-camel/src/test/java/org/apache/james/mailetcontainer/impl/matchers/OrTest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailetcontainer.impl.matchers;

import static org.apache.mailet.base.MailAddressFixture.ANY_AT_JAMES;
import static org.apache.mailet.base.MailAddressFixture.ANY_AT_JAMES2;
import static org.apache.mailet.base.MailAddressFixture.OTHER_AT_JAMES;
import static org.apache.mailet.base.MailAddressFixture.OTHER_AT_JAMES2;
import static org.assertj.core.api.Assertions.assertThat;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import org.apache.james.core.MailAddress;
import org.apache.james.server.core.MailImpl;
import org.apache.mailet.Mail;
import org.apache.mailet.Matcher;
import org.junit.Before;
import org.junit.Test;

import com.google.common.collect.ImmutableList;

public class OrTest {

    private Or testee;
    private Matcher matcher1;
    private Matcher matcher2;
    private Mail mail;

    @Before
    public void setUp() throws Exception {
        matcher1 = mock(Matcher.class);
        matcher2 = mock(Matcher.class);

        testee = new Or();

        mail = MailImpl.builder().name("name").addRecipients(ANY_AT_JAMES, OTHER_AT_JAMES, ANY_AT_JAMES2, OTHER_AT_JAMES2).build();
    }

    @Test
    public void shouldReturnNoResultWhenNoMatcherSpecified() throws Exception {
        assertThat(testee.match(mail)).isEmpty();
    }

    @Test
    public void shouldReturnMatchResultWhenOnlyOneMatcher() throws Exception {
        when(matcher1.match(mail)).thenReturn(ImmutableList.of(ANY_AT_JAMES, ANY_AT_JAMES2));

        testee.add(matcher1);

        assertThat(testee.match(mail)).containsOnly(ANY_AT_JAMES, ANY_AT_JAMES2);
    }

    @Test
    public void shouldReturnUnionWhenTwoMatchers() throws Exception {
        when(matcher1.match(mail)).thenReturn(ImmutableList.of(ANY_AT_JAMES, ANY_AT_JAMES2));
        when(matcher2.match(mail)).thenReturn(ImmutableList.of(ANY_AT_JAMES, OTHER_AT_JAMES));

        testee.add(matcher1);
        testee.add(matcher2);

        assertThat(testee.match(mail)).containsOnly(ANY_AT_JAMES, ANY_AT_JAMES2, OTHER_AT_JAMES);
    }

    @Test
    public void shouldAcceptEmptyResults() throws Exception {
        when(matcher1.match(mail)).thenReturn(ImmutableList.of(ANY_AT_JAMES, ANY_AT_JAMES2));
        when(matcher2.match(mail)).thenReturn(ImmutableList.<MailAddress>of());

        testee.add(matcher1);
        testee.add(matcher2);

        assertThat(testee.match(mail)).containsOnly(ANY_AT_JAMES, ANY_AT_JAMES2);
    }

    @Test
    public void shouldAcceptNullResults() throws Exception {
        when(matcher1.match(mail)).thenReturn(ImmutableList.of(ANY_AT_JAMES, ANY_AT_JAMES2));
        when(matcher2.match(mail)).thenReturn(null);

        testee.add(matcher1);
        testee.add(matcher2);

        assertThat(testee.match(mail)).containsOnly(ANY_AT_JAMES, ANY_AT_JAMES2);
    }
}
